==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/zh_CN.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "此服务器未启用服务器到服务器分享功能",
    "Invalid or untrusted SSL certificate" : "不合法或是不被信任的 SSL 证书",
    "Couldn't add remote share" : "无法添加远程分享",
    "Shared with you" : "分享给您的文件",
    "Shared with others" : "您分享的文件",
    "Shared by link" : "分享链接的文件",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "您要添加 {name} 来自 {owner}@{remote} 的远程分享吗？",
    "Remote share" : "远程分享",
    "Remote share password" : "远程分享密码",
    "Cancel" : "取消",
    "Add remote share" : "添加远程分享",
    "You can upload into this folder" : "您可以上传文件至此文件夹",
    "No ownCloud installation (7 or higher) found at {remote}" : "未发现 {remote} 安装有ownCloud (7 或更高版本)",
    "Invalid ownCloud url" : "无效的 ownCloud 网址",
    "Shared by" : "共享人",
    "Sharing" : "共享",
    "A file or folder has been <strong>shared</strong>" : "一个文件或文件夹已<strong>共享</strong>。",
    "You received a new remote share from %s" : "您从%s收到了新的远程分享",
    "You shared %1$s with %2$s" : "您把 %1$s分享给了 %2$s",
    "You shared %1$s with group %2$s" : "你把 %1$s 分享给了 %2$s 组",
    "%2$s shared %1$s with you" : "%2$s 把 %1$s 分享给了您",
    "You shared %1$s via link" : "您通过链接共享了 %1$s",
    "Shares" : "共享",
    "This share is password-protected" : "这是一个密码保护的共享",
    "The password is wrong. Try again." : "用户名或密码错误！请重试",
    "Password" : "密码",
    "No entries found in this folder" : "此文件夹中无项目",
    "Name" : "名称",
    "Share time" : "分享时间",
    "Sorry, this link doesn’t seem to work anymore." : "抱歉，此链接已失效",
    "Reasons might be:" : "可能原因是：",
    "the item was removed" : "此项已移除",
    "the link expired" : "链接过期",
    "sharing is disabled" : "分享已禁用",
    "For more info, please ask the person who sent this link." : "欲知详情，请联系发给你链接的人。",
    "Add to your ownCloud" : "添加到您的 ownCloud",
    "Download" : "下载",
    "Download %s" : "下载 %s",
    "Direct link" : "直接链接",
    "Federated Cloud Sharing" : "联合云共享",
    "Open documentation" : "打开文档",
    "Allow users on this server to send shares to other servers" : "允许用户分享文件给其他服务器上的用户",
    "Allow users on this server to receive shares from other servers" : "允许用户从其他服务器接收分享",
    "HTML Code:" : "HTML 代码:"
},
"nplurals=1; plural=0;");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/zh_CN.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "此服务器未启用服务器到服务器分享功能",
    "Invalid or untrusted SSL certificate" : "不合法或是不被信任的 SSL 证书",
    "Couldn't add remote share" : "无法添加远程分享",
    "Shared with you" : "分享给您的文件",
    "Shared with others" : "您分享的文件",
    "Shared by link" : "分享链接的文件",
    "Federated sharing" : "联合云共享",
    "Nothing shared with you yet" : "你还没有收到任何共享的文件",
    "Nothing shared yet" : "还没有共享过文件",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "您要添加 {name} 来自 {owner}@{remote} 的远程分享吗？",
    "Remote share" : "远程分享",
    "Remote share password" : "远程分享密码",
    "Cancel" : "取消",
    "Add remote share" : "添加远程分享",
    "You can upload into this folder" : "您可以上传文件至此文件夹",
    "No ownCloud installation (7 or higher) found at {remote}" : "未发现 {remote} 安装有ownCloud (7 或更高版本)",
    "Invalid ownCloud url" : "无效的 ownCloud 网址",
    "Shared by" : "共享人",
    "Sharing" : "共享",
    "A file or folder has been <strong>shared</strong>" : "一个文件或文件夹已<strong>共享</strong>。",
    "You received a new remote share from %s" : "您从%s收到了新的远程分享",
    "You shared %1$s with %2$s" : "您把 %1$s分享给了 %2$s",
    "You shared %1$s with group %2$s" : "你把 %1$s 分享给了 %2$s 组",
    "You shared %1$s via link" : "您通过链接共享了 %1$s",
    "%2$s shared %1$s with you" : "%2$s 把 %1$s 分享给了您",
    "Downloaded via public link" : "通过公开链接下载",
    "Shared with %2$s" : "共享给 %2$s",
    "Shared with %3$s by %2$s" : "由 %2$s 共享给 %3$s",
    "Shared with group %2$s" : "共享给组%2$s",
    "Shared with group %3$s by %2$s" : "由 %2$s 共享给组 %3$s",
    "Shared via public link" : "通过公开链接共享",
    "Removed public link" : "移除公开链接",
    "Public link expired" : "公开链接已过期",
    "Shares" : "共享",
    "Accept" : "接受",
    "Decline" : "拒绝",
    "This share is password-protected" : "这是一个密码保护的共享",
    "The password is wrong. Try again." : "用户名或密码错误！请重试",
    "Password" : "密码",
    "No entries found in this folder" : "此文件夹中无项目",
    "Name" : "名称",
    "Share time" : "分享时间",
    "Sorry, this link doesn’t seem to work anymore." : "抱歉，此链接已失效",
    "Reasons might be:" : "可能原因是：",
    "the item was removed" : "此项已移除",
    "the link expired" : "链接过期",
    "sharing is disabled" : "分享已禁用",
    "For more info, please ask the person who sent this link." : "欲知详情，请联系发给你链接的人。",
    "Add to your ownCloud" : "添加到您的 ownCloud",
    "Download" : "下载",
    "Download %s" : "下载 %s",
    "Direct link" : "直接链接",
    "Federated Cloud Sharing" : "联合云共享",
    "Open documentation" : "打开文档",
    "Allow users on this server to send shares to other servers" : "允许用户分享文件给其他服务器上的用户",
    "Allow users on this server to receive shares from other servers" : "允许用户从其他服务器接收分享",
    "Federated Cloud" : "联合云",
    "Your Federated Cloud ID:" : "你的联合云ID：",
    "Share with me via ownCloud" : "通过联合云与我共享",
    "HTML Code:" : "HTML 代码:"
},
"nplurals=1; plural=0;");
